@@ -43,12 +43,13 @@ require AutoLoader;
       ConfigureError FatalErrorException
     );
 
-$VERSION = '6.99';
+$VERSION = '6.9A';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
     # XS function.  If a constant is not found then control is passed
     # to the AUTOLOAD in AutoLoader.
+    no warnings;
 
     my $constname;
     ($constname = $AUTOLOAD) =~ s/.*:://;
